aboutsummaryrefslogtreecommitdiff
path: root/libraries/Ethernet
diff options
context:
space:
mode:
Diffstat (limited to 'libraries/Ethernet')
-rw-r--r--libraries/Ethernet/Client.h34
-rwxr-xr-xlibraries/Ethernet/Dhcp.cpp30
-rwxr-xr-xlibraries/Ethernet/Dhcp.h5
-rw-r--r--libraries/Ethernet/Dns.cpp12
-rw-r--r--libraries/Ethernet/Dns.h6
-rw-r--r--libraries/Ethernet/Ethernet.cpp18
-rw-r--r--libraries/Ethernet/Ethernet.h13
-rw-r--r--libraries/Ethernet/EthernetClient.cpp (renamed from libraries/Ethernet/Client.cpp)59
-rw-r--r--libraries/Ethernet/EthernetClient.h37
-rw-r--r--libraries/Ethernet/EthernetServer.cpp (renamed from libraries/Ethernet/Server.cpp)39
-rw-r--r--libraries/Ethernet/EthernetServer.h22
-rw-r--r--libraries/Ethernet/EthernetUdp.cpp (renamed from libraries/Ethernet/Udp.cpp)43
-rw-r--r--libraries/Ethernet/EthernetUdp.h (renamed from libraries/Ethernet/Udp.h)35
-rw-r--r--libraries/Ethernet/IPAddress.cpp44
-rw-r--r--libraries/Ethernet/IPAddress.h72
-rw-r--r--libraries/Ethernet/Server.h22
-rw-r--r--libraries/Ethernet/examples/BarometricPressureWebServer/BarometricPressureWebServer.ino (renamed from libraries/Ethernet/examples/BarometricPressureWebServer/BarometricPressureWebServer.pde)8
-rw-r--r--libraries/Ethernet/examples/ChatServer/ChatServer.ino (renamed from libraries/Ethernet/examples/ChatServer/ChatServer.pde)4
-rw-r--r--libraries/Ethernet/examples/DhcpAddressPrinter/DhcpAddressPrinter.ino (renamed from libraries/Ethernet/examples/DhcpAddressPrinter/DhcpAddressPrinter.pde)2
-rw-r--r--libraries/Ethernet/examples/DhcpChatServer/DhcpChatServer.ino80
-rw-r--r--libraries/Ethernet/examples/DnsWebClient/DnsWebClient.ino (renamed from libraries/Ethernet/examples/DnsWebClient/DnsWebClient.pde)2
-rw-r--r--libraries/Ethernet/examples/PachubeClient/PachubeClient.ino (renamed from libraries/Ethernet/examples/PachubeClient/PachubeClient.pde)13
-rw-r--r--libraries/Ethernet/examples/PachubeClientString/PachubeClientString.ino (renamed from libraries/Ethernet/examples/PachubeClientString/PachubeClientString.pde)19
-rw-r--r--libraries/Ethernet/examples/TelnetClient/TelnetClient.ino (renamed from libraries/Ethernet/examples/TelnetClient/TelnetClient.pde)2
-rw-r--r--libraries/Ethernet/examples/TwitterClient/TwitterClient.ino124
-rw-r--r--libraries/Ethernet/examples/UDPSendReceiveString/UDPSendReceiveString.ino (renamed from libraries/Ethernet/examples/UDPSendReceiveString/UDPSendReceiveString.pde)6
-rw-r--r--libraries/Ethernet/examples/UdpNtpClient/UdpNtpClient.ino (renamed from libraries/Ethernet/examples/UdpNtpClient/UdpNtpClient.pde)4
-rw-r--r--libraries/Ethernet/examples/WebClient/WebClient.ino (renamed from libraries/Ethernet/examples/WebClient/WebClient.pde)2
-rw-r--r--libraries/Ethernet/examples/WebServer/WebServer.ino (renamed from libraries/Ethernet/examples/WebServer/WebServer.pde)6
-rw-r--r--libraries/Ethernet/keywords.txt4
-rw-r--r--libraries/Ethernet/util.h2
-rw-r--r--libraries/Ethernet/utility/socket.cpp7
-rwxr-xr-xlibraries/Ethernet/utility/socket.h2
-rw-r--r--libraries/Ethernet/utility/w5100.cpp4
-rwxr-xr-xlibraries/Ethernet/utility/w5100.h9
35 files changed, 462 insertions, 329 deletions
diff --git a/libraries/Ethernet/Client.h b/libraries/Ethernet/Client.h
deleted file mode 100644
index 582f493..0000000
--- a/libraries/Ethernet/Client.h
+++ /dev/null
@@ -1,34 +0,0 @@
-#ifndef client_h
-#define client_h
-#include "Arduino.h"
-#include "Print.h"
-
-class Client : public Stream {
-
-public:
- Client();
- Client(uint8_t sock);
-
- uint8_t status();
- int connect(IPAddress ip, uint16_t port);
- int connect(const char *host, uint16_t port);
- virtual void write(uint8_t);
- virtual void write(const char *str);
- virtual void write(const uint8_t *buf, size_t size);
- virtual int available();
- virtual int read();
- virtual int read(uint8_t *buf, size_t size);
- virtual int peek();
- virtual void flush();
- void stop();
- uint8_t connected();
- operator bool();
-
- friend class Server;
-
-private:
- static uint16_t _srcport;
- uint8_t _sock;
-};
-
-#endif
diff --git a/libraries/Ethernet/Dhcp.cpp b/libraries/Ethernet/Dhcp.cpp
index c20d2e6..62bbfeb 100755
--- a/libraries/Ethernet/Dhcp.cpp
+++ b/libraries/Ethernet/Dhcp.cpp
@@ -163,15 +163,15 @@ void DhcpClass::send_DHCP_MESSAGE(uint8_t messageType, uint16_t secondsElapsed)
// OPT - host name
buffer[16] = hostName;
- buffer[17] = strlen(HOST_NAME) + 3; // length of hostname + last 3 bytes of mac address
+ buffer[17] = strlen(HOST_NAME) + 6; // length of hostname + last 3 bytes of mac address
strcpy((char*)&(buffer[18]), HOST_NAME);
- buffer[24] = _dhcpMacAddr[3];
- buffer[25] = _dhcpMacAddr[4];
- buffer[26] = _dhcpMacAddr[5];
+ printByte((char*)&(buffer[24]), _dhcpMacAddr[3]);
+ printByte((char*)&(buffer[26]), _dhcpMacAddr[4]);
+ printByte((char*)&(buffer[28]), _dhcpMacAddr[5]);
//put data in W5100 transmit buffer
- _dhcpUdpSocket.write(buffer, 27);
+ _dhcpUdpSocket.write(buffer, 30);
if(messageType == DHCP_REQUEST)
{
@@ -243,7 +243,7 @@ uint8_t DhcpClass::parseDHCPResponse(unsigned long responseTimeout, uint32_t& tr
// Skip to the option part
// Doing this a byte at a time so we don't have to put a big buffer
// on the stack (as we don't have lots of memory lying around)
- for (int i =0; i < (240 - sizeof(RIP_MSG_FIXED)); i++)
+ for (int i =0; i < (240 - (int)sizeof(RIP_MSG_FIXED)); i++)
{
_dhcpUdpSocket.read(); // we don't care about the returned byte
}
@@ -271,11 +271,19 @@ uint8_t DhcpClass::parseDHCPResponse(unsigned long responseTimeout, uint32_t& tr
case routersOnSubnet :
opt_len = _dhcpUdpSocket.read();
_dhcpUdpSocket.read(_dhcpGatewayIp, 4);
+ for (int i = 0; i < opt_len-4; i++)
+ {
+ _dhcpUdpSocket.read();
+ }
break;
case dns :
opt_len = _dhcpUdpSocket.read();
_dhcpUdpSocket.read(_dhcpDnsServerIp, 4);
+ for (int i = 0; i < opt_len-4; i++)
+ {
+ _dhcpUdpSocket.read();
+ }
break;
case dhcpServerIdentifier :
@@ -339,3 +347,13 @@ IPAddress DhcpClass::getDnsServerIp()
return IPAddress(_dhcpDnsServerIp);
}
+void DhcpClass::printByte(char * buf, uint8_t n ) {
+ char *str = &buf[1];
+ buf[0]='0';
+ do {
+ unsigned long m = n;
+ n /= 16;
+ char c = m - 16 * n;
+ *str-- = c < 10 ? c + '0' : c + 'A' - 10;
+ } while(n);
+}
diff --git a/libraries/Ethernet/Dhcp.h b/libraries/Ethernet/Dhcp.h
index c003494..149876d 100755
--- a/libraries/Ethernet/Dhcp.h
+++ b/libraries/Ethernet/Dhcp.h
@@ -4,7 +4,7 @@
#ifndef Dhcp_h
#define Dhcp_h
-#include "Udp.h"
+#include "EthernetUdp.h"
/* DHCP state machine. */
#define STATE_DHCP_START 0
@@ -139,10 +139,11 @@ private:
uint8_t _dhcpGatewayIp[4];
uint8_t _dhcpDhcpServerIp[4];
uint8_t _dhcpDnsServerIp[4];
- UDP _dhcpUdpSocket;
+ EthernetUDP _dhcpUdpSocket;
void presend_DHCP();
void send_DHCP_MESSAGE(uint8_t, uint16_t);
+ void printByte(char *, uint8_t);
uint8_t parseDHCPResponse(unsigned long responseTimeout, uint32_t& transactionId);
public:
diff --git a/libraries/Ethernet/Dns.cpp b/libraries/Ethernet/Dns.cpp
index a049c76..b3c1a9d 100644
--- a/libraries/Ethernet/Dns.cpp
+++ b/libraries/Ethernet/Dns.cpp
@@ -3,7 +3,7 @@
// Released under Apache License, version 2.0
#include "w5100.h"
-#include "Udp.h"
+#include "EthernetUdp.h"
#include "util.h"
#include "Dns.h"
@@ -252,7 +252,7 @@ uint16_t DNSClient::BuildRequest(const char* aName)
}
-uint16_t DNSClient::ProcessResponse(int aTimeout, IPAddress& aAddress)
+uint16_t DNSClient::ProcessResponse(uint16_t aTimeout, IPAddress& aAddress)
{
uint32_t startTime = millis();
@@ -285,7 +285,7 @@ uint16_t DNSClient::ProcessResponse(int aTimeout, IPAddress& aAddress)
uint16_t header_flags = htons(*((uint16_t*)&header[2]));
// Check that it's a response to this request
if ( ( iRequestId != (*((uint16_t*)&header[0])) ) ||
- (header_flags & QUERY_RESPONSE_MASK != RESPONSE_FLAG) )
+ ((header_flags & QUERY_RESPONSE_MASK) != (uint16_t)RESPONSE_FLAG) )
{
// Mark the entire packet as read
iUdp.flush();
@@ -310,7 +310,7 @@ uint16_t DNSClient::ProcessResponse(int aTimeout, IPAddress& aAddress)
}
// Skip over any questions
- for (int i =0; i < htons(*((uint16_t*)&header[4])); i++)
+ for (uint16_t i =0; i < htons(*((uint16_t*)&header[4])); i++)
{
// Skip over the name
uint8_t len;
@@ -340,7 +340,7 @@ uint16_t DNSClient::ProcessResponse(int aTimeout, IPAddress& aAddress)
// type A answer) and some authority and additional resource records but
// we're going to ignore all of them.
- for (int i =0; i < answerCount; i++)
+ for (uint16_t i =0; i < answerCount; i++)
{
// Skip the name
uint8_t len;
@@ -407,7 +407,7 @@ uint16_t DNSClient::ProcessResponse(int aTimeout, IPAddress& aAddress)
else
{
// This isn't an answer type we're after, move onto the next one
- for (int i =0; i < htons(header_flags); i++)
+ for (uint16_t i =0; i < htons(header_flags); i++)
{
iUdp.read(); // we don't care about the returned byte
}
diff --git a/libraries/Ethernet/Dns.h b/libraries/Ethernet/Dns.h
index 9582351..6bcb98a 100644
--- a/libraries/Ethernet/Dns.h
+++ b/libraries/Ethernet/Dns.h
@@ -5,7 +5,7 @@
#ifndef DNSClient_h
#define DNSClient_h
-#include <Udp.h>
+#include <EthernetUdp.h>
class DNSClient
{
@@ -31,11 +31,11 @@ public:
protected:
uint16_t BuildRequest(const char* aName);
- uint16_t ProcessResponse(int aTimeout, IPAddress& aAddress);
+ uint16_t ProcessResponse(uint16_t aTimeout, IPAddress& aAddress);
IPAddress iDNSServer;
uint16_t iRequestId;
- UDP iUdp;
+ EthernetUDP iUdp;
};
#endif
diff --git a/libraries/Ethernet/Ethernet.cpp b/libraries/Ethernet/Ethernet.cpp
index 937f5b4..c298f3d 100644
--- a/libraries/Ethernet/Ethernet.cpp
+++ b/libraries/Ethernet/Ethernet.cpp
@@ -34,26 +34,36 @@ int EthernetClass::begin(uint8_t *mac_address)
void EthernetClass::begin(uint8_t *mac_address, IPAddress local_ip)
{
+ // Assume the DNS server will be the machine on the same network as the local IP
+ // but with last octet being '1'
+ IPAddress dns_server = local_ip;
+ dns_server[3] = 1;
+ begin(mac_address, local_ip, dns_server);
+}
+
+void EthernetClass::begin(uint8_t *mac_address, IPAddress local_ip, IPAddress dns_server)
+{
// Assume the gateway will be the machine on the same network as the local IP
// but with last octet being '1'
IPAddress gateway = local_ip;
gateway[3] = 1;
- begin(mac_address, local_ip, gateway);
+ begin(mac_address, local_ip, dns_server, gateway);
}
-void EthernetClass::begin(uint8_t *mac_address, IPAddress local_ip, IPAddress gateway)
+void EthernetClass::begin(uint8_t *mac_address, IPAddress local_ip, IPAddress dns_server, IPAddress gateway)
{
IPAddress subnet(255, 255, 255, 0);
- begin(mac_address, local_ip, gateway, subnet);
+ begin(mac_address, local_ip, dns_server, gateway, subnet);
}
-void EthernetClass::begin(uint8_t *mac, IPAddress local_ip, IPAddress gateway, IPAddress subnet)
+void EthernetClass::begin(uint8_t *mac, IPAddress local_ip, IPAddress dns_server, IPAddress gateway, IPAddress subnet)
{
W5100.init();
W5100.setMACAddress(mac);
W5100.setIPAddress(local_ip._address);
W5100.setGatewayIp(gateway._address);
W5100.setSubnetMask(subnet._address);
+ _dnsServerAddress = dns_server;
}
IPAddress EthernetClass::localIP()
diff --git a/libraries/Ethernet/Ethernet.h b/libraries/Ethernet/Ethernet.h
index fdf0b7f..c916dda 100644
--- a/libraries/Ethernet/Ethernet.h
+++ b/libraries/Ethernet/Ethernet.h
@@ -4,8 +4,8 @@
#include <inttypes.h>
//#include "w5100.h"
#include "IPAddress.h"
-#include "Client.h"
-#include "Server.h"
+#include "EthernetClient.h"
+#include "EthernetServer.h"
#define MAX_SOCK_NUM 4
@@ -20,16 +20,17 @@ public:
// Returns 0 if the DHCP configuration failed, and 1 if it succeeded
int begin(uint8_t *mac_address);
void begin(uint8_t *mac_address, IPAddress local_ip);
- void begin(uint8_t *mac_address, IPAddress local_ip, IPAddress gateway);
- void begin(uint8_t *mac_address, IPAddress local_ip, IPAddress gateway, IPAddress subnet);
+ void begin(uint8_t *mac_address, IPAddress local_ip, IPAddress dns_server);
+ void begin(uint8_t *mac_address, IPAddress local_ip, IPAddress dns_server, IPAddress gateway);
+ void begin(uint8_t *mac_address, IPAddress local_ip, IPAddress dns_server, IPAddress gateway, IPAddress subnet);
IPAddress localIP();
IPAddress subnetMask();
IPAddress gatewayIP();
IPAddress dnsServerIP();
- friend class Client;
- friend class Server;
+ friend class EthernetClient;
+ friend class EthernetServer;
};
extern EthernetClass Ethernet;
diff --git a/libraries/Ethernet/EthernetClient.h b/libraries/Ethernet/EthernetClient.h
new file mode 100644
index 0000000..44740fe
--- /dev/null
+++ b/libraries/Ethernet/EthernetClient.h
@@ -0,0 +1,37 @@
+#ifndef ethernetclient_h
+#define ethernetclient_h
+#include "Arduino.h"
+#include "Print.h"
+#include "Client.h"
+#include "IPAddress.h"
+
+class EthernetClient : public Client {
+
+public:
+ EthernetClient();
+ EthernetClient(uint8_t sock);
+
+ uint8_t status();
+ virtual int connect(IPAddress ip, uint16_t port);
+ virtual int connect(const char *host, uint16_t port);
+ virtual size_t write(uint8_t);
+ virtual size_t write(const uint8_t *buf, size_t size);
+ virtual int available();
+ virtual int read();
+ virtual int read(uint8_t *buf, size_t size);
+ virtual int peek();
+ virtual void flush();
+ virtual void stop();
+ virtual uint8_t connected();
+ virtual operator bool();
+
+ friend class EthernetServer;
+
+ using Print::write;
+
+private:
+ static uint16_t _srcport;
+ uint8_t _sock;
+};
+
+#endif
diff --git a/libraries/Ethernet/Server.cpp b/libraries/Ethernet/EthernetServer.cpp
index 4271741..0308b92 100644
--- a/libraries/Ethernet/Server.cpp
+++ b/libraries/Ethernet/EthernetServer.cpp
@@ -5,18 +5,18 @@ extern "C" {
}
#include "Ethernet.h"
-#include "Client.h"
-#include "Server.h"
+#include "EthernetClient.h"
+#include "EthernetServer.h"
-Server::Server(uint16_t port)
+EthernetServer::EthernetServer(uint16_t port)
{
_port = port;
}
-void Server::begin()
+void EthernetServer::begin()
{
for (int sock = 0; sock < MAX_SOCK_NUM; sock++) {
- Client client(sock);
+ EthernetClient client(sock);
if (client.status() == SnSR::CLOSED) {
socket(sock, SnMR::TCP, _port, 0);
listen(sock);
@@ -26,12 +26,12 @@ void Server::begin()
}
}
-void Server::accept()
+void EthernetServer::accept()
{
int listening = 0;
for (int sock = 0; sock < MAX_SOCK_NUM; sock++) {
- Client client(sock);
+ EthernetClient client(sock);
if (EthernetClass::_server_port[sock] == _port) {
if (client.status() == SnSR::LISTEN) {
@@ -48,12 +48,12 @@ void Server::accept()
}
}
-Client Server::available()
+EthernetClient EthernetServer::available()
{
accept();
for (int sock = 0; sock < MAX_SOCK_NUM; sock++) {
- Client client(sock);
+ EthernetClient client(sock);
if (EthernetClass::_server_port[sock] == _port &&
(client.status() == SnSR::ESTABLISHED ||
client.status() == SnSR::CLOSE_WAIT)) {
@@ -64,29 +64,28 @@ Client Server::available()
}
}
- return Client(MAX_SOCK_NUM);
+ return EthernetClient(MAX_SOCK_NUM);
}
-void Server::write(uint8_t b)
+size_t EthernetServer::write(uint8_t b)
{
- write(&b, 1);
+ return write(&b, 1);
}
-void Server::write(const char *str)
-{
- write((const uint8_t *)str, strlen(str));
-}
-
-void Server::write(const uint8_t *buffer, size_t size)
+size_t EthernetServer::write(const uint8_t *buffer, size_t size)
{
+ size_t n = 0;
+
accept();
for (int sock = 0; sock < MAX_SOCK_NUM; sock++) {
- Client client(sock);
+ EthernetClient client(sock);
if (EthernetClass::_server_port[sock] == _port &&
client.status() == SnSR::ESTABLISHED) {
- client.write(buffer, size);
+ n += client.write(buffer, size);
}
}
+
+ return n;
}
diff --git a/libraries/Ethernet/EthernetServer.h b/libraries/Ethernet/EthernetServer.h
new file mode 100644
index 0000000..86ccafe
--- /dev/null
+++ b/libraries/Ethernet/EthernetServer.h
@@ -0,0 +1,22 @@
+#ifndef ethernetserver_h
+#define ethernetserver_h
+
+#include "Server.h"
+
+class EthernetClient;
+
+class EthernetServer :
+public Server {
+private:
+ uint16_t _port;
+ void accept();
+public:
+ EthernetServer(uint16_t);
+ EthernetClient available();
+ virtual void begin();
+ virtual size_t write(uint8_t);
+ virtual size_t write(const uint8_t *buf, size_t size);
+ using Print::write;
+};
+
+#endif
diff --git a/libraries/Ethernet/Udp.h b/libraries/Ethernet/EthernetUdp.h
index 99df53f..9a2b653 100644
--- a/libraries/Ethernet/Udp.h
+++ b/libraries/Ethernet/EthernetUdp.h
@@ -34,15 +34,14 @@
* bjoern@cs.stanford.edu 12/30/2008
*/
-#ifndef udp_h
-#define udp_h
+#ifndef ethernetudp_h
+#define ethernetudp_h
-#include <Stream.h>
-#include <IPAddress.h>
+#include <Udp.h>
#define UDP_TX_PACKET_MAX_SIZE 24
-class UDP : public Stream {
+class EthernetUDP : public UDP {
private:
uint8_t _sock; // socket ID for Wiz5100
uint16_t _port; // local port to listen on
@@ -51,31 +50,31 @@ private:
uint16_t _offset; // offset into the packet being sent
public:
- UDP(); // Constructor
- uint8_t begin(uint16_t); // initialize, start listening on specified port. Returns 1 if successful, 0 if there are no sockets available to use
- void stop(); // Finish with the UDP socket
+ EthernetUDP(); // Constructor
+ virtual uint8_t begin(uint16_t); // initialize, start listening on specified port. Returns 1 if successful, 0 if there are no sockets available to use
+ virtual void stop(); // Finish with the UDP socket
// Sending UDP packets
// Start building up a packet to send to the remote host specific in ip and port
// Returns 1 if successful, 0 if there was a problem with the supplied IP address or port
- int beginPacket(IPAddress ip, uint16_t port);
+ virtual int beginPacket(IPAddress ip, uint16_t port);
// Start building up a packet to send to the remote host specific in host and port
// Returns 1 if successful, 0 if there was a problem resolving the hostname or port
- int beginPacket(const char *host, uint16_t port);
+ virtual int beginPacket(const char *host, uint16_t port);
// Finish off this packet and send it
// Returns 1 if the packet was sent successfully, 0 if there was an error
- int endPacket();
+ virtual int endPacket();
// Write a single byte into the packet
- virtual void write(uint8_t);
- // Write a string of characters into the packet
- virtual void write(const char *str);
+ virtual size_t write(uint8_t);
// Write size bytes from buffer into the packet
- virtual void write(const uint8_t *buffer, size_t size);
+ virtual size_t write(const uint8_t *buffer, size_t size);
+
+ using Print::write;
// Start processing the next available incoming packet
// Returns the size of the packet in bytes, or 0 if no packets are available
- int parsePacket();
+ virtual int parsePacket();
// Number of bytes remaining in the current packet
virtual int available();
// Read a single byte from the current packet
@@ -91,9 +90,9 @@ public:
virtual void flush(); // Finish reading the current packet
// Return the IP address of the host who sent the current incoming packet
- IPAddress remoteIP() { return _remoteIP; };
+ virtual IPAddress remoteIP() { return _remoteIP; };
// Return the port of the host who sent the current incoming packet
- uint16_t remotePort() { return _remotePort; };
+ virtual uint16_t remotePort() { return _remotePort; };
};
#endif
diff --git a/libraries/Ethernet/IPAddress.cpp b/libraries/Ethernet/IPAddress.cpp
deleted file mode 100644
index 610ff4c..0000000
--- a/libraries/Ethernet/IPAddress.cpp
+++ /dev/null
@@ -1,44 +0,0 @@
-
-#include <Arduino.h>
-#include <IPAddress.h>
-
-IPAddress::IPAddress()
-{
- memset(_address, 0, sizeof(_address));
-}
-
-IPAddress::IPAddress(uint8_t first_octet, uint8_t second_octet, uint8_t third_octet, uint8_t fourth_octet)
-{
- _address[0] = first_octet;
- _address[1] = second_octet;
- _address[2] = third_octet;
- _address[3] = fourth_octet;
-}
-
-IPAddress::IPAddress(uint32_t address)
-{
- memcpy(_address, &address, sizeof(_address));
-}
-
-IPAddress::IPAddress(const uint8_t *address)
-{
- memcpy(_address, address, sizeof(_address));
-}
-
-IPAddress& IPAddress::operator=(const uint8_t *address)
-{
- memcpy(_address, address, sizeof(_address));
- return *this;
-}
-
-IPAddress& IPAddress::operator=(uint32_t address)
-{
- memcpy(_address, (const uint8_t *)&address, sizeof(_address));
- return *this;
-}
-
-bool IPAddress::operator==(const uint8_t* addr)
-{
- return memcmp(addr, _address, sizeof(_address)) == 0;
-}
-
diff --git a/libraries/Ethernet/IPAddress.h b/libraries/Ethernet/IPAddress.h
deleted file mode 100644
index 487e420..0000000
--- a/libraries/Ethernet/IPAddress.h
+++ /dev/null
@@ -1,72 +0,0 @@
-/*
- *
- * MIT License:
- * Copyright (c) 2011 Adrian McEwen
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in
- * all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
- * THE SOFTWARE.
- *
- * adrianm@mcqn.com 1/1/2011
- */
-
-#ifndef IPAddress_h
-#define IPAddress_h
-
-// A class to make it easier to handle and pass around IP addresses
-
-class IPAddress {
-private:
- uint8_t _address[4]; // IPv4 address
- // Access the raw byte array containing the address. Because this returns a pointer
- // to the internal structure rather than a copy of the address this function should only
- // be used when you know that the usage of the returned uint8_t* will be transient and not
- // stored.
- uint8_t* raw_address() { return _address; };
-
-public:
- // Constructors
- IPAddress();
- IPAddress(uint8_t first_octet, uint8_t second_octet, uint8_t third_octet, uint8_t fourth_octet);
- IPAddress(uint32_t address);
- IPAddress(const uint8_t *address);
-
- // Overloaded cast operator to allow IPAddress objects to be used where a pointer
- // to a four-byte uint8_t array is expected
- operator uint32_t() { return *((uint32_t*)_address); };
- bool operator==(const IPAddress& addr) { return (*((uint32_t*)_address)) == (*((uint32_t*)addr._address)); };
- bool operator==(const uint8_t* addr);
-
- // Overloaded index operator to allow getting and setting individual octets of the address
- uint8_t operator[](int index) const { return _address[index]; };
- uint8_t& operator[](int index) { return _address[index]; };
-
- // Overloaded copy operators to allow initialisation of IPAddress objects from other types
- IPAddress& operator=(const uint8_t *address);
- IPAddress& operator=(uint32_t address);
-
- friend class EthernetClass;
- friend class UDP;
- friend class Client;
- friend class Server;
- friend class DhcpClass;
- friend class DNSClient;
-};
-
-const IPAddress INADDR_NONE(0,0,0,0);
-
-
-#endif
diff --git a/libraries/Ethernet/Server.h b/libraries/Ethernet/Server.h
deleted file mode 100644
index 6aa5d3a..0000000
--- a/libraries/Ethernet/Server.h
+++ /dev/null
@@ -1,22 +0,0 @@
-#ifndef server_h
-#define server_h
-
-#include "Print.h"
-
-class Client;
-
-class Server :
-public Print {
-private:
- uint16_t _port;
- void accept();
-public:
- Server(uint16_t);
- Client available();
- void begin();
- virtual void write(uint8_t);
- virtual void write(const char *str);
- virtual void write(const uint8_t *buf, size_t size);
-};
-
-#endif
diff --git a/libraries/Ethernet/examples/BarometricPressureWebServer/BarometricPressureWebServer.pde b/libraries/Ethernet/examples/BarometricPressureWebServer/BarometricPressureWebServer.ino
index 3f43d96..bfbcb6d 100644
--- a/libraries/Ethernet/examples/BarometricPressureWebServer/BarometricPressureWebServer.pde
+++ b/libraries/Ethernet/examples/BarometricPressureWebServer/BarometricPressureWebServer.ino
@@ -39,7 +39,7 @@ IPAddress subnet(255, 255, 255, 0);
// Initialize the Ethernet server library
// with the IP address and port you want to use
// (port 80 is default for HTTP):
-Server server(80);
+EthernetServer server(80);
//Sensor's memory register addresses:
@@ -96,7 +96,7 @@ void loop() {
}
// listen for incoming Ethernet connections:
- listenForClients();
+ listenForEthernetClients();
}
@@ -124,9 +124,9 @@ void getData() {
Serial.println(" Pa");
}
-void listenForClients() {
+void listenForEthernetClients() {
// listen for incoming clients
- Client client = server.available();
+ EthernetClient client = server.available();
if (client) {
Serial.println("Got a client");
// an http request ends with a blank line
diff --git a/libraries/Ethernet/examples/ChatServer/ChatServer.pde b/libraries/Ethernet/examples/ChatServer/ChatServer.ino
index 8267a5d..9f819fd 100644
--- a/libraries/Ethernet/examples/ChatServer/ChatServer.pde
+++ b/libraries/Ethernet/examples/ChatServer/ChatServer.ino
@@ -29,7 +29,7 @@ IPAddress gateway(192,168,1, 1);
IPAddress subnet(255, 255, 0, 0);
// telnet defaults to port 23
-Server server(23);
+EthernetServer server(23);
boolean gotAMessage = false; // whether or not you got a message from the client yet
void setup() {
@@ -43,7 +43,7 @@ void setup() {
void loop() {
// wait for a new client:
- Client client = server.available();
+ EthernetClient client = server.available();
// when the client sends the first byte, say hello:
if (client) {
diff --git a/libraries/Ethernet/examples/DhcpAddressPrinter/DhcpAddressPrinter.pde b/libraries/Ethernet/examples/DhcpAddressPrinter/DhcpAddressPrinter.ino
index 50a557d..630dd17 100644
--- a/libraries/Ethernet/examples/DhcpAddressPrinter/DhcpAddressPrinter.pde
+++ b/libraries/Ethernet/examples/DhcpAddressPrinter/DhcpAddressPrinter.ino
@@ -24,7 +24,7 @@ byte mac[] = {
// Initialize the Ethernet client library
// with the IP address and port of the server
// that you want to connect to (port 80 is default for HTTP):
-Client client;
+EthernetClient client;
void setup() {
// start the serial library:
diff --git a/libraries/Ethernet/examples/DhcpChatServer/DhcpChatServer.ino b/libraries/Ethernet/examples/DhcpChatServer/DhcpChatServer.ino
new file mode 100644
index 0000000..5082054
--- /dev/null
+++ b/libraries/Ethernet/examples/DhcpChatServer/DhcpChatServer.ino
@@ -0,0 +1,80 @@
+/*
+ DHCP Chat Server
+
+ A simple server that distributes any incoming messages to all
+ connected clients. To use telnet to your device's IP address and type.
+ You can see the client's input in the serial monitor as well.
+ Using an Arduino Wiznet Ethernet shield.
+
+ THis version attempts to get an IP address using DHCP
+
+ Circuit:
+ * Ethernet shield attached to pins 10, 11, 12, 13
+
+ created 21 May 2011
+ by Tom Igoe
+ Based on ChatServer example by David A. Mellis
+
+ */
+
+#include <SPI.h>
+#include <Ethernet.h>
+
+// Enter a MAC address and IP address for your controller below.
+// The IP address will be dependent on your local network.
+// gateway and subnet are optional:
+byte mac[] = {
+ 0x00, 0xAA, 0xBB, 0xCC, 0xDE, 0x02 };
+IPAddress ip(192,168,1, 177);
+IPAddress gateway(192,168,1, 1);
+IPAddress subnet(255, 255, 0, 0);
+
+// telnet defaults to port 23
+EthernetServer server(23);
+boolean gotAMessage = false; // whether or not you got a message from the client yet
+
+void setup() {
+ // open the serial port
+ Serial.begin(9600);
+ // start the Ethernet connection:
+ Serial.println("Trying to get an IP address using DHCP");
+ if (Ethernet.begin(mac) == 0) {
+ Serial.println("Failed to configure Ethernet using DHCP");
+ // initialize the ethernet device not using DHCP:
+ Ethernet.begin(mac, ip, gateway, subnet);
+ }
+ // print your local IP address:
+ Serial.print("My IP address: ");
+ ip = Ethernet.localIP();
+ for (byte thisByte = 0; thisByte < 4; thisByte++) {
+ // print the value of each byte of the IP address:
+ Serial.print(ip[thisByte], DEC);
+ Serial.print(".");
+ }
+ Serial.println();
+ // start listening for clients
+ server.begin();
+
+}
+
+void loop() {
+ // wait for a new client:
+ EthernetClient client = server.available();
+
+ // when the client sends the first byte, say hello:
+ if (client) {
+ if (!gotAMessage) {
+ Serial.println("We have a new client");
+ client.println("Hello, client!");
+ gotAMessage = true;
+ }
+
+ // read the bytes incoming from the client:
+ char thisChar = client.read();
+ // echo the bytes back to the client:
+ server.write(thisChar);
+ // echo the bytes to the server as well:
+ Serial.print(thisChar);
+ }
+}
+
diff --git a/libraries/Ethernet/examples/DnsWebClient/DnsWebClient.pde b/libraries/Ethernet/examples/DnsWebClient/DnsWebClient.ino
index 7bec73a..5c7a53a 100644
--- a/libraries/Ethernet/examples/DnsWebClient/DnsWebClient.pde
+++ b/libraries/Ethernet/examples/DnsWebClient/DnsWebClient.ino
@@ -25,7 +25,7 @@ char serverName[] = "www.google.com";
// Initialize the Ethernet client library
// with the IP address and port of the server
// that you want to connect to (port 80 is default for HTTP):
-Client client;
+EthernetClient client;
void setup() {
// start the serial library:
diff --git a/libraries/Ethernet/examples/PachubeClient/PachubeClient.pde b/libraries/Ethernet/examples/PachubeClient/PachubeClient.ino
index af9bf1f..a169443 100644
--- a/libraries/Ethernet/examples/PachubeClient/PachubeClient.pde
+++ b/libraries/Ethernet/examples/PachubeClient/PachubeClient.ino
@@ -11,7 +11,7 @@
* Ethernet shield attached to pins 10, 11, 12, 13
created 15 March 2010
- updated 4 Sep 2010
+ updated 26 Oct 2011
by Tom Igoe
http://www.tigoe.net/pcomp/code/category/arduinowiring/873
@@ -28,8 +28,11 @@
byte mac[] = {
0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED};
+// fill in an available IP address on your network here,
+// for manual configuration:
+IPAddress ip(10,0,1,20);
// initialize the library instance:
-Client client;
+EthernetClient client;
long lastConnectionTime = 0; // last time you connected to the server, in milliseconds
boolean lastConnected = false; // state of the connection last time through the main loop
@@ -47,6 +50,12 @@ void setup() {
}
// give the ethernet module time to boot up:
delay(1000);
+ // start the Ethernet connection:
+ if (Ethernet.begin(mac) == 0) {
+ Serial.println("Failed to configure Ethernet using DHCP");
+ // Configure manually:
+ Ethernet.begin(mac, ip);
+ }
}
void loop() {
diff --git a/libraries/Ethernet/examples/PachubeClientString/PachubeClientString.pde b/libraries/Ethernet/examples/PachubeClientString/PachubeClientString.ino
index e6dbf09..4a03100 100644
--- a/libraries/Ethernet/examples/PachubeClientString/PachubeClientString.pde
+++ b/libraries/Ethernet/examples/PachubeClientString/PachubeClientString.ino
@@ -14,7 +14,7 @@
* Ethernet shield attached to pins 10, 11, 12, 13
created 15 March 2010
- updated 4 Sep 2010
+ updated 26 Oct 2011
by Tom Igoe
This code is in the public domain.
@@ -28,25 +28,28 @@
// fill in your address here:
byte mac[] = {
0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0xED};
+// fill in an available IP address on your network here,
+// for manual configuration:
+IPAddress ip(10,0,1,20);
// initialize the library instance:
-Client client;
+EthernetClient client;
long lastConnectionTime = 0; // last time you connected to the server, in milliseconds
boolean lastConnected = false; // state of the connection last time through the main loop
const int postingInterval = 10000; //delay between updates to Pachube.com
void setup() {
- // start the ethernet connection and serial port:
+ // start serial port:
Serial.begin(9600);
+ // give the ethernet module time to boot up:
+ delay(1000);
+ // start the Ethernet connection:
if (Ethernet.begin(mac) == 0) {
Serial.println("Failed to configure Ethernet using DHCP");
- // no point in carrying on, so do nothing forevermore:
- for(;;)
- ;
+ // Configure manually:
+ Ethernet.begin(mac, ip);
}
- // give the ethernet module time to boot up:
- delay(1000);
}
void loop() {
diff --git a/libraries/Ethernet/examples/TelnetClient/TelnetClient.pde b/libraries/Ethernet/examples/TelnetClient/TelnetClient.ino
index 7502d21..5cf1ad8 100644
--- a/libraries/Ethernet/examples/TelnetClient/TelnetClient.pde
+++ b/libraries/Ethernet/examples/TelnetClient/TelnetClient.ino
@@ -33,7 +33,7 @@ IPAddress server(1,1,1,1);
// with the IP address and port of the server
// that you want to connect to (port 23 is default for telnet;
// if you're using Processing's ChatServer, use port 10002):
-Client client;
+EthernetClient client;
void setup() {
// start the Ethernet connection:
diff --git a/libraries/Ethernet/examples/TwitterClient/TwitterClient.ino b/libraries/Ethernet/examples/TwitterClient/TwitterClient.ino
new file mode 100644
index 0000000..f113e17
--- /dev/null
+++ b/libraries/Ethernet/examples/TwitterClient/TwitterClient.ino
@@ -0,0 +1,124 @@
+/*
+ Twitter Client with Strings
+
+ This sketch connects to Twitter using an Ethernet shield. It parses the XML
+ returned, and looks for <text>this is a tweet</text>
+
+ You can use the Arduino Ethernet shield, or the Adafruit Ethernet shield,
+ either one will work, as long as it's got a Wiznet Ethernet module on board.
+
+ This example uses the DHCP routines in the Ethernet library which is part of the
+ Arduino core from version 1.0 beta 1
+
+ This example uses the String library, which is part of the Arduino core from
+ version 0019.
+
+ Circuit:
+ * Ethernet shield attached to pins 10, 11, 12, 13
+
+ created 21 May 2011
+ by Tom Igoe
+
+ This code is in the public domain.
+
+ */
+#include <SPI.h>
+#include <Ethernet.h>
+
+
+// Enter a MAC address and IP address for your controller below.
+// The IP address will be dependent on your local network:
+byte mac[] = {
+ 0x00, 0xAA, 0xBB, 0xCC, 0xDE, 0x01 };
+IPAddress ip(192,168,1,20);
+
+// initialize the library instance:
+EthernetClient client;
+
+const int requestInterval = 60000; // delay between requests
+
+char serverName[] = "api.twitter.com"; // twitter URL
+
+boolean requested; // whether you've made a request since connecting
+long lastAttemptTime = 0; // last time you connected to the server, in milliseconds
+
+String currentLine = ""; // string to hold the text from server
+String tweet = ""; // string to hold the tweet
+boolean readingTweet = false; // if you're currently reading the tweet
+
+void setup() {
+ // reserve space for the strings:
+ currentLine.reserve(256);
+ tweet.reserve(150);
+
+// initialize serial:
+ Serial.begin(9600);
+ // attempt a DHCP connection:
+ if (!Ethernet.begin(mac)) {
+ // if DHCP fails, start with a hard-coded address:
+ Ethernet.begin(mac, ip);
+ }
+ // connect to Twitter:
+ connectToServer();
+}
+
+
+
+void loop()
+{
+ if (client.connected()) {
+ if (client.available()) {
+ // read incoming bytes:
+ char inChar = client.read();
+
+ // add incoming byte to end of line:
+ currentLine += inChar;
+
+ // if you get a newline, clear the line:
+ if (inChar == '\n') {
+ currentLine = "";
+ }
+ // if the current line ends with <text>, it will
+ // be followed by the tweet:
+ if ( currentLine.endsWith("<text>")) {
+ // tweet is beginning. Clear the tweet string:
+ readingTweet = true;
+ tweet = "";
+ }
+ // if you're currently reading the bytes of a tweet,
+ // add them to the tweet String:
+ if (readingTweet) {
+ if (inChar != '<') {
+ tweet += inChar;
+ }
+ else {
+ // if you got a "<" character,
+ // you've reached the end of the tweet:
+ readingTweet = false;
+ Serial.println(tweet);
+ // close the connection to the server:
+ client.stop();
+ }
+ }
+ }
+ }
+ else if (millis() - lastAttemptTime > requestInterval) {
+ // if you're not connected, and two minutes have passed since
+ // your last connection, then attempt to connect again:
+ connectToServer();
+ }
+}
+
+void connectToServer() {
+ // attempt to connect, and wait a millisecond:
+ Serial.println("connecting to server...");
+ if (client.connect(serverName, 80)) {
+ Serial.println("making HTTP request...");
+ // make HTTP GET request to twitter:
+ client.println("GET /1/statuses/user_timeline.xml?screen_name=arduino&count=1 HTTP/1.1");
+ client.println("HOST: api.twitter.com");
+ client.println();
+ }
+ // note the time of this connect attempt:
+ lastAttemptTime = millis();
+}
diff --git a/libraries/Ethernet/examples/UDPSendReceiveString/UDPSendReceiveString.pde b/libraries/Ethernet/examples/UDPSendReceiveString/UDPSendReceiveString.ino
index 081d691..4d4045c 100644
--- a/libraries/Ethernet/examples/UDPSendReceiveString/UDPSendReceiveString.pde
+++ b/libraries/Ethernet/examples/UDPSendReceiveString/UDPSendReceiveString.ino
@@ -15,7 +15,7 @@
#include <SPI.h> // needed for Arduino versions later than 0018
#include <Ethernet.h>
-#include <Udp.h> // UDP library from: bjoern@cs.stanford.edu 12/30/2008
+#include <EthernetUdp.h> // UDP library from: bjoern@cs.stanford.edu 12/30/2008
// Enter a MAC address and IP address for your controller below.
@@ -30,8 +30,8 @@ unsigned int localPort = 8888; // local port to listen on
char packetBuffer[UDP_TX_PACKET_MAX_SIZE]; //buffer to hold incoming packet,
char ReplyBuffer[] = "acknowledged"; // a string to send back
-// A UDP instance to let us send and receive packets over UDP
-UDP Udp;
+// An EthernetUDP instance to let us send and receive packets over UDP
+EthernetUDP Udp;
void setup() {
// start the Ethernet and UDP:
diff --git a/libraries/Ethernet/examples/UdpNtpClient/UdpNtpClient.pde b/libraries/Ethernet/examples/UdpNtpClient/UdpNtpClient.ino
index 7c2d3ea..b4e24b8 100644
--- a/libraries/Ethernet/examples/UdpNtpClient/UdpNtpClient.pde
+++ b/libraries/Ethernet/examples/UdpNtpClient/UdpNtpClient.ino
@@ -18,7 +18,7 @@
#include <SPI.h>
#include <Ethernet.h>
-#include <Udp.h>
+#include <EthernetUdp.h>
// Enter a MAC address for your controller below.
// Newer Ethernet shields have a MAC address printed on a sticker on the shield
@@ -34,7 +34,7 @@ const int NTP_PACKET_SIZE= 48; // NTP time stamp is in the first 48 bytes of the
byte packetBuffer[ NTP_PACKET_SIZE]; //buffer to hold incoming and outgoing packets
// A UDP instance to let us send and receive packets over UDP
-UDP Udp;
+EthernetUDP Udp;
void setup()
{
diff --git a/libraries/Ethernet/examples/WebClient/WebClient.pde b/libraries/Ethernet/examples/WebClient/WebClient.ino
index 646c3aa..1806854 100644
--- a/libraries/Ethernet/examples/WebClient/WebClient.pde
+++ b/libraries/Ethernet/examples/WebClient/WebClient.ino
@@ -23,7 +23,7 @@ IPAddress server(173,194,33,104); // Google
// Initialize the Ethernet client library
// with the IP address and port of the server
// that you want to connect to (port 80 is default for HTTP):
-Client client;
+EthernetClient client;
void setup() {
// start the serial library:
diff --git a/libraries/Ethernet/examples/WebServer/WebServer.pde b/libraries/Ethernet/examples/WebServer/WebServer.ino
index c69a56a..6837f83 100644
--- a/libraries/Ethernet/examples/WebServer/WebServer.pde
+++ b/libraries/Ethernet/examples/WebServer/WebServer.ino
@@ -1,5 +1,5 @@
/*
- Web Server
+ Web Server
A simple web server that shows the value of the analog input pins.
using an Arduino Wiznet Ethernet shield.
@@ -26,7 +26,7 @@ IPAddress ip(192,168,1, 177);
// Initialize the Ethernet server library
// with the IP address and port you want to use
// (port 80 is default for HTTP):
-Server server(80);
+EthernetServer server(80);
void setup()
{
@@ -38,7 +38,7 @@ void setup()
void loop()
{
// listen for incoming clients
- Client client = server.available();
+ EthernetClient client = server.available();
if (client) {
// an http request ends with a blank line
boolean currentLineIsBlank = true;
diff --git a/libraries/Ethernet/keywords.txt b/libraries/Ethernet/keywords.txt
index 7fdcedf..6b37cbe 100644
--- a/libraries/Ethernet/keywords.txt
+++ b/libraries/Ethernet/keywords.txt
@@ -7,8 +7,8 @@
#######################################
Ethernet KEYWORD1
-Client KEYWORD1
-Server KEYWORD1
+EthernetClient KEYWORD1
+EthernetServer KEYWORD1
IPAddress KEYWORD1
#######################################
diff --git a/libraries/Ethernet/util.h b/libraries/Ethernet/util.h
index 220011b..5042e82 100644
--- a/libraries/Ethernet/util.h
+++ b/libraries/Ethernet/util.h
@@ -1,7 +1,7 @@
#ifndef UTIL_H
#define UTIL_H
-#define htons(x) ( (x)<<8 | ((x)>>8)&0xFF )
+#define htons(x) ( ((x)<<8) | (((x)>>8)&0xFF) )
#define ntohs(x) htons(x)
#define htonl(x) ( ((x)<<24 & 0xFF000000UL) | \
diff --git a/libraries/Ethernet/utility/socket.cpp b/libraries/Ethernet/utility/socket.cpp
index 4875845..fd3e442 100644
--- a/libraries/Ethernet/utility/socket.cpp
+++ b/libraries/Ethernet/utility/socket.cpp
@@ -9,7 +9,6 @@ static uint16_t local_port;
*/
uint8_t socket(SOCKET s, uint8_t protocol, uint16_t port, uint8_t flag)
{
- uint8_t ret;
if ((protocol == SnMR::TCP) || (protocol == SnMR::UDP) || (protocol == SnMR::IPRAW) || (protocol == SnMR::MACRAW) || (protocol == SnMR::PPPOE))
{
close(s);
@@ -144,15 +143,15 @@ uint16_t send(SOCKET s, const uint8_t * buf, uint16_t len)
*
* @return received data size for success else -1.
*/
-uint16_t recv(SOCKET s, uint8_t *buf, uint16_t len)
+int16_t recv(SOCKET s, uint8_t *buf, int16_t len)
{
// Check how much data is available
- uint16_t ret = W5100.getRXReceivedSize(s);
+ int16_t ret = W5100.getRXReceivedSize(s);
if ( ret == 0 )
{
// No data available.
uint8_t status = W5100.readSnSR(s);
- if ( s == SnSR::LISTEN || s == SnSR::CLOSED || s == SnSR::CLOSE_WAIT )
+ if ( status == SnSR::LISTEN || status == SnSR::CLOSED || status == SnSR::CLOSE_WAIT )
{
// The remote end has closed its side of the connection, so this is the eof state
ret = 0;
diff --git a/libraries/Ethernet/utility/socket.h b/libraries/Ethernet/utility/socket.h
index 37ea93f..45e0fb3 100755
--- a/libraries/Ethernet/utility/socket.h
+++ b/libraries/Ethernet/utility/socket.h
@@ -9,7 +9,7 @@ extern uint8_t connect(SOCKET s, uint8_t * addr, uint16_t port); // Establish TC
extern void disconnect(SOCKET s); // disconnect the connection
extern uint8_t listen(SOCKET s); // Establish TCP connection (Passive connection)
extern uint16_t send(SOCKET s, const uint8_t * buf, uint16_t len); // Send data (TCP)
-extern uint16_t recv(SOCKET s, uint8_t * buf, uint16_t len); // Receive data (TCP)
+extern int16_t recv(SOCKET s, uint8_t * buf, int16_t len); // Receive data (TCP)
extern uint16_t peek(SOCKET s, uint8_t *buf);
extern uint16_t sendto(SOCKET s, const uint8_t * buf, uint16_t len, uint8_t * addr, uint16_t port); // Send data (UDP/IP RAW)
extern uint16_t recvfrom(SOCKET s, uint8_t * buf, uint16_t len, uint8_t * addr, uint16_t *port); // Receive data (UDP/IP RAW)
diff --git a/libraries/Ethernet/utility/w5100.cpp b/libraries/Ethernet/utility/w5100.cpp
index aafabae..9c748fd 100644
--- a/libraries/Ethernet/utility/w5100.cpp
+++ b/libraries/Ethernet/utility/w5100.cpp
@@ -140,7 +140,7 @@ uint8_t W5100Class::write(uint16_t _addr, uint8_t _data)
uint16_t W5100Class::write(uint16_t _addr, const uint8_t *_buf, uint16_t _len)
{
- for (int i=0; i<_len; i++)
+ for (uint16_t i=0; i<_len; i++)
{
setSS();
SPI.transfer(0xF0);
@@ -166,7 +166,7 @@ uint8_t W5100Class::read(uint16_t _addr)
uint16_t W5100Class::read(uint16_t _addr, uint8_t *_buf, uint16_t _len)
{
- for (int i=0; i<_len; i++)
+ for (uint16_t i=0; i<_len; i++)
{
setSS();
SPI.transfer(0x0F);
diff --git a/libraries/Ethernet/utility/w5100.h b/libraries/Ethernet/utility/w5100.h
index 9872c7c..153aedb 100755
--- a/libraries/Ethernet/utility/w5100.h
+++ b/libraries/Ethernet/utility/w5100.h
@@ -270,7 +270,10 @@ private:
} \
static uint16_t read##name(SOCKET _s) { \
uint16_t res = readSn(_s, address); \
- res = (res << 8) + readSn(_s, address + 1); \
+ uint16_t res2 = readSn(_s,address + 1); \
+ res = res << 8; \
+ res2 = res2 & 0xFF; \
+ res = res | res2; \
return res; \
}
#define __SOCKET_REGISTER_N(name, address, size) \
@@ -324,6 +327,10 @@ private:
inline static void initSS() { DDRB |= _BV(4); };
inline static void setSS() { PORTB &= ~_BV(4); };
inline static void resetSS() { PORTB |= _BV(4); };
+#elif defined(__AVR_ATmega32U4__) || defined(__AVR_AT90USB1286__) || defined(__AVR_AT90USB646__) || defined(__AVR_AT90USB162__)
+ inline static void initSS() { DDRB |= _BV(0); };
+ inline static void setSS() { PORTB &= ~_BV(0); };
+ inline static void resetSS() { PORTB |= _BV(0); };
#else
inline static void initSS() { DDRB |= _BV(2); };
inline static void setSS() { PORTB &= ~_BV(2); };
diff --git a/libraries/Ethernet/Client.cpp b/libraries/Ethernet/EthernetClient.cpp
index f146ac5..a77a62b 100644
--- a/libraries/Ethernet/Client.cpp
+++ b/libraries/Ethernet/EthernetClient.cpp
@@ -8,19 +8,19 @@ extern "C" {
#include "Arduino.h"
#include "Ethernet.h"
-#include "Client.h"
-#include "Server.h"
+#include "EthernetClient.h"
+#include "EthernetServer.h"
#include "Dns.h"
-uint16_t Client::_srcport = 1024;
+uint16_t EthernetClient::_srcport = 1024;
-Client::Client() : _sock(MAX_SOCK_NUM) {
+EthernetClient::EthernetClient() : _sock(MAX_SOCK_NUM) {
}
-Client::Client(uint8_t sock) : _sock(sock) {
+EthernetClient::EthernetClient(uint8_t sock) : _sock(sock) {
}
-int Client::connect(const char* host, uint16_t port) {
+int EthernetClient::connect(const char* host, uint16_t port) {
// Look up the host first
int ret = 0;
DNSClient dns;
@@ -35,7 +35,7 @@ int Client::connect(const char* host, uint16_t port) {
}
}
-int Client::connect(IPAddress ip, uint16_t port) {
+int EthernetClient::connect(IPAddress ip, uint16_t port) {
if (_sock != MAX_SOCK_NUM)
return 0;
@@ -54,7 +54,7 @@ int Client::connect(IPAddress ip, uint16_t port) {
if (_srcport == 0) _srcport = 1024;
socket(_sock, SnMR::TCP, _srcport, 0);
- if (!::connect(_sock, ip.raw_address(), port)) {
+ if (!::connect(_sock, rawIPAddress(ip), port)) {
_sock = MAX_SOCK_NUM;
return 0;
}
@@ -70,28 +70,29 @@ int Client::connect(IPAddress ip, uint16_t port) {
return 1;
}
-void Client::write(uint8_t b) {
- if (_sock != MAX_SOCK_NUM)
- send(_sock, &b, 1);
+size_t EthernetClient::write(uint8_t b) {
+ return write(&b, 1);
}
-void Client::write(const char *str) {
- if (_sock != MAX_SOCK_NUM)
- send(_sock, (const uint8_t *)str, strlen(str));
-}
-
-void Client::write(const uint8_t *buf, size_t size) {
- if (_sock != MAX_SOCK_NUM)
- send(_sock, buf, size);
+size_t EthernetClient::write(const uint8_t *buf, size_t size) {
+ if (_sock == MAX_SOCK_NUM) {
+ setWriteError();
+ return 0;
+ }
+ if (!send(_sock, buf, size)) {
+ setWriteError();
+ return 0;
+ }
+ return size;
}
-int Client::available() {
+int EthernetClient::available() {
if (_sock != MAX_SOCK_NUM)
return W5100.getRXReceivedSize(_sock);
return 0;
}
-int Client::read() {
+int EthernetClient::read() {
uint8_t b;
if ( recv(_sock, &b, 1) > 0 )
{
@@ -105,11 +106,11 @@ int Client::read() {
}
}
-int Client::read(uint8_t *buf, size_t size) {
+int EthernetClient::read(uint8_t *buf, size_t size) {
return recv(_sock, buf, size);
}
-int Client::peek() {
+int EthernetClient::peek() {
uint8_t b;
// Unlike recv, peek doesn't check to see if there's any data available, so we must
if (!available())
@@ -118,12 +119,12 @@ int Client::peek() {
return b;
}
-void Client::flush() {
+void EthernetClient::flush() {
while (available())
read();
}
-void Client::stop() {
+void EthernetClient::stop() {
if (_sock == MAX_SOCK_NUM)
return;
@@ -143,7 +144,7 @@ void Client::stop() {
_sock = MAX_SOCK_NUM;
}
-uint8_t Client::connected() {
+uint8_t EthernetClient::connected() {
if (_sock == MAX_SOCK_NUM) return 0;
uint8_t s = status();
@@ -151,14 +152,14 @@ uint8_t Client::connected() {
(s == SnSR::CLOSE_WAIT && !available()));
}
-uint8_t Client::status() {
+uint8_t EthernetClient::status() {
if (_sock == MAX_SOCK_NUM) return SnSR::CLOSED;
return W5100.readSnSR(_sock);
}
// the next function allows us to use the client returned by
-// Server::available() as the condition in an if-statement.
+// EthernetServer::available() as the condition in an if-statement.
-Client::operator bool() {
+EthernetClient::operator bool() {
return _sock != MAX_SOCK_NUM;
}
diff --git a/libraries/Ethernet/Udp.cpp b/libraries/Ethernet/EthernetUdp.cpp
index aed5d98..9c752fc 100644
--- a/libraries/Ethernet/Udp.cpp
+++ b/libraries/Ethernet/EthernetUdp.cpp
@@ -33,10 +33,10 @@
#include "Dns.h"
/* Constructor */
-UDP::UDP() : _sock(MAX_SOCK_NUM) {}
+EthernetUDP::EthernetUDP() : _sock(MAX_SOCK_NUM) {}
-/* Start UDP socket, listening at local port PORT */
-uint8_t UDP::begin(uint16_t port) {
+/* Start EthernetUDP socket, listening at local port PORT */
+uint8_t EthernetUDP::begin(uint16_t port) {
if (_sock != MAX_SOCK_NUM)
return 0;
@@ -59,12 +59,12 @@ uint8_t UDP::begin(uint16_t port) {
/* Is data available in rx buffer? Returns 0 if no, number of available bytes if yes.
* returned value includes 8 byte UDP header!*/
-int UDP::available() {
+int EthernetUDP::available() {
return W5100.getRXReceivedSize(_sock);
}
-/* Release any resources being used by this UDP instance */
-void UDP::stop()
+/* Release any resources being used by this EthernetUDP instance */
+void EthernetUDP::stop()
{
if (_sock == MAX_SOCK_NUM)
return;
@@ -75,7 +75,7 @@ void UDP::stop()
_sock = MAX_SOCK_NUM;
}
-int UDP::beginPacket(const char *host, uint16_t port)
+int EthernetUDP::beginPacket(const char *host, uint16_t port)
{
// Look up the host first
int ret = 0;
@@ -91,35 +91,30 @@ int UDP::beginPacket(const char *host, uint16_t port)
}
}
-int UDP::beginPacket(IPAddress ip, uint16_t port)
+int EthernetUDP::beginPacket(IPAddress ip, uint16_t port)
{
_offset = 0;
- return startUDP(_sock, ip.raw_address(), port);
+ return startUDP(_sock, rawIPAddress(ip), port);
}
-int UDP::endPacket()
+int EthernetUDP::endPacket()
{
return sendUDP(_sock);
}
-void UDP::write(uint8_t byte)
+size_t EthernetUDP::write(uint8_t byte)
{
- write(&byte, 1);
+ return write(&byte, 1);
}
-void UDP::write(const char *str)
-{
- size_t len = strlen(str);
- write((const uint8_t *)str, len);
-}
-
-void UDP::write(const uint8_t *buffer, size_t size)
+size_t EthernetUDP::write(const uint8_t *buffer, size_t size)
{
uint16_t bytes_written = bufferData(_sock, _offset, buffer, size);
_offset += bytes_written;
+ return bytes_written;
}
-int UDP::parsePacket()
+int EthernetUDP::parsePacket()
{
if (available() > 0)
{
@@ -142,7 +137,7 @@ int UDP::parsePacket()
return 0;
}
-int UDP::read()
+int EthernetUDP::read()
{
uint8_t byte;
if (recv(_sock, &byte, 1) > 0)
@@ -154,7 +149,7 @@ int UDP::read()
return -1;
}
-int UDP::read(unsigned char* buffer, size_t len)
+int EthernetUDP::read(unsigned char* buffer, size_t len)
{
/* In the readPacket that copes with truncating packets, the buffer was
filled with this code. Not sure why it loops round reading out a byte
@@ -168,7 +163,7 @@ int UDP::read(unsigned char* buffer, size_t len)
return recv(_sock, buffer, len);
}
-int UDP::peek()
+int EthernetUDP::peek()
{
uint8_t b;
// Unlike recv, peek doesn't check to see if there's any data available, so we must
@@ -178,7 +173,7 @@ int UDP::peek()
return b;
}
-void UDP::flush()
+void EthernetUDP::flush()
{
while (available())
{